--[[
-- Copyright 2017 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
-- ]]

--[[
-- In this module we define the various game specific powers that we have
-- available. These powers are all combat actions that resolve into one or
-- more of the atomic combat actions: attack, move, inflict, summon, and
-- modifier.
--
-- They allow the user to do extra damage, receive less damage, and just
-- generally bend or break the rules of combat.
]]

local M = {}

local powertables = {
    require 'data/scarletmoonpowers',
    require 'data/buzzsawpowers',
    require 'data/succubuspowers',
    require 'data/poseidonpowers',
    require 'data/prometheuspowers',
    require 'data/tempestaspowers',
    require 'data/anklyanapowers',
    require 'data/leopardpowers',
    require 'data/brightpowers'
}

for _, table in pairs(powertables) do
    for name, power in pairs(table) do
        M[name] = power
    end
end

for _, characterpowers in pairs(require 'data/princesspowers') do
    for name, power in pairs(characterpowers) do
        M[name] = power
    end
end

return M
