--[[
-- Copyright 2017 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]
--
--[[
-- This module is responsible for loading and providing access to the story
-- events written by the game writer. The module provides a function `page`
-- that takes the name of an event, a transformer and returns the associated event.
--
-- The module also has a table `pages`, that can be accessed directly if
-- necessary, but that is not recommended.
--]]

local M = {}
local scarletfunctions = require './scarletfunctions'

--[[
-- Given the configuration, the name of a story page, and an (optional)
-- operation on gamestate, returns a shallow copy of the story page with the
-- specified operation as its transformer.
--
-- configuration: The current configuration for the game
-- name: The name of the page to look up
-- transformer: The operation on gamestate to use as this page's transformer
--]]
function M.page(configuration, name, transformer)
    local state = require 'state'
    local configuredpage = state.getstory(configuration, name)
    local page = {}
    for key, value in pairs(configuredpage) do
        page[key] = value
    end
    page.transformer = transformer or scarletfunctions.identity
    return page
end

return M

